@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: FOUserAgent.java 1873298 2020-01-29 11:28:26Z ssteiner $ */
+/* $Id: FOUserAgent.java 1885366 2021-01-11 15:00:20Z ssteiner $ */
 
 package org.apache.fop.apps;
 
@@ -413,7 +413,7 @@ public class FOUserAgent {
         try {
             // Have to do this so we can resolve data URIs
             StreamSource src = new StreamSource(resourceResolver.getResource(uri));
-            src.setSystemId(uri);
+            src.setSystemId(getResourceResolver().getBaseURI().toASCIIString());
             return src;
         } catch (URISyntaxException use) {
             return null;
@@ -831,4 +831,8 @@ public class FOUserAgent {
             return true;
         }
     }
+
+    public boolean isTableBorderOverpaint() {
+        return factory.isTableBorderOverpaint();
+    }
 }
