@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: FopFactory.java 1873298 2020-01-29 11:28:26Z ssteiner $ */
+/* $Id: FopFactory.java 1884907 2020-12-29 13:33:34Z ssteiner $ */
 
 package org.apache.fop.apps;
 
@@ -207,6 +207,10 @@ public final class FopFactory implements ImageContext {
         return userAgent.newFop(outputFormat, null);
     }
 
+    boolean isTableBorderOverpaint() {
+        return config.isTableBorderOverpaint();
+    }
+
     /**
      * Returns a new {@link Fop} instance. FOP will be configured with a default user agent
      * instance. Use this factory method if your output type requires an output stream.
