@@ -160,6 +160,11 @@ public final class FopFactoryBuilder {
         return this;
     }
 
+    public FopFactoryBuilder setKeepEmptyTags(boolean b) {
+        fopFactoryConfigBuilder.setKeepEmptyTags(b);
+        return this;
+    }
+
     /**
      * Sets the {@link LayoutManagerMaker} so that users can configure how FOP creates
      * {@link org.apache.fop.layoutmgr.LayoutManager}s.
@@ -322,6 +327,11 @@ public final class FopFactoryBuilder {
         return this;
     }
 
+    public FopFactoryBuilder setTableBorderOverpaint(boolean b) {
+        fopFactoryConfigBuilder.setTableBorderOverpaint(b);
+        return this;
+    }
+
     public static class FopFactoryConfigImpl implements FopFactoryConfig {
 
         private final EnvironmentProfile enviro;
@@ -330,6 +340,8 @@ public final class FopFactoryBuilder {
 
         private boolean accessibility;
 
+        private boolean keepEmptyTags = true;
+
         private LayoutManagerMaker layoutManagerMaker;
 
         private URI baseURI;
@@ -361,6 +373,8 @@ public final class FopFactoryBuilder {
 
         private Map<String, String> hyphPatNames;
 
+        private boolean tableBorderOverpaint;
+
         private static final class ImageContextImpl implements ImageContext {
 
             private final FopFactoryConfig config;
@@ -385,6 +399,10 @@ public final class FopFactoryBuilder {
             return accessibility;
         }
 
+        public boolean isKeepEmptyTags() {
+            return keepEmptyTags;
+        }
+
         /** {@inheritDoc} */
         public LayoutManagerMaker getLayoutManagerMakerOverride() {
             return layoutManagerMaker;
@@ -473,6 +491,10 @@ public final class FopFactoryBuilder {
             return isComplexScript;
         }
 
+        public boolean isTableBorderOverpaint() {
+            return tableBorderOverpaint;
+        }
+
         public Map<String, String> getHyphenationPatternNames() {
             return hyphPatNames;
         }
@@ -485,6 +507,7 @@ public final class FopFactoryBuilder {
     private interface FopFactoryConfigBuilder {
 
         void setAccessibility(boolean enableAccessibility);
+        void setKeepEmptyTags(boolean b);
 
         void setLayoutManagerMakerOverride(LayoutManagerMaker lmMaker);
 
@@ -517,6 +540,8 @@ public final class FopFactoryBuilder {
         void setComplexScriptFeaturesEnabled(boolean csf);
 
         void setHyphPatNames(Map<String, String> hyphPatNames);
+
+        void setTableBorderOverpaint(boolean b);
     }
 
     private static final class CompletedFopFactoryConfigBuilder implements FopFactoryConfigBuilder {
@@ -531,6 +556,9 @@ public final class FopFactoryBuilder {
         public void setAccessibility(boolean enableAccessibility) {
             throwIllegalStateException();
         }
+        public void setKeepEmptyTags(boolean b) {
+            throwIllegalStateException();
+        }
 
         public void setLayoutManagerMakerOverride(LayoutManagerMaker lmMaker) {
             throwIllegalStateException();
@@ -598,6 +626,9 @@ public final class FopFactoryBuilder {
             throwIllegalStateException();
         }
 
+        public void setTableBorderOverpaint(boolean b) {
+            throwIllegalStateException();
+        }
     }
 
     private static final class ActiveFopFactoryConfigBuilder implements FopFactoryConfigBuilder {
@@ -612,6 +643,10 @@ public final class FopFactoryBuilder {
             config.accessibility = enableAccessibility;
         }
 
+        public void setKeepEmptyTags(boolean b) {
+            config.keepEmptyTags = b;
+        }
+
         public void setLayoutManagerMakerOverride(LayoutManagerMaker lmMaker) {
             config.layoutManagerMaker = lmMaker;
         }
@@ -678,6 +713,10 @@ public final class FopFactoryBuilder {
         public void setHyphPatNames(Map<String, String> hyphPatNames) {
             config.hyphPatNames = hyphPatNames;
         }
+
+        public void setTableBorderOverpaint(boolean b) {
+            config.tableBorderOverpaint = b;
+        }
     }
 
 }
