@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: AbstractBreaker.java 1875645 2020-03-25 14:44:35Z ssteiner $ */
+/* $Id: AbstractBreaker.java 1878744 2020-06-11 08:46:18Z ssteiner $ */
 
 package org.apache.fop.layoutmgr;
 
@@ -412,7 +412,7 @@ public abstract class AbstractBreaker {
                 boolean ipdChangesOnNextPage = (alg.getIPDdifference() != 0);
                 boolean onLastPageAndIPDChanges = false;
                 if (!ipdChangesOnNextPage) {
-                    onLastPageAndIPDChanges = (lastPageHasIPDChange() && !thereIsANonRestartableLM(alg)
+                    onLastPageAndIPDChanges = (lastPageHasIPDChange(optimalPageCount) && !thereIsANonRestartableLM(alg)
                             && (shouldRedoLayout() || (wasLayoutRedone() && optimalPageCount > 1)));
                 }
                 if ((ipdChangesOnNextPage || hasMoreContent() || optimalPageCount > 1)
@@ -774,7 +774,7 @@ public abstract class AbstractBreaker {
         return false;
     }
 
-    protected boolean lastPageHasIPDChange() {
+    protected boolean lastPageHasIPDChange(int optimalPageCount) {
         return false;
     }
 
