@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PageBreaker.java 1814394 2017-11-06 11:36:57Z ssteiner $ */
+/* $Id: PageBreaker.java 1880106 2020-07-21 13:28:42Z ssteiner $ */
 
 package org.apache.fop.layoutmgr;
 
@@ -68,6 +68,7 @@ public class PageBreaker extends AbstractBreaker {
     private MinOptMax relayedFootnoteSeparatorLength;
     private int previousFootnoteListIndex = -2;
     private int previousFootnoteElementIndex = -2;
+    private int prevousColumnCount;
 
     /**
      * The FlowLayoutManager object, which processes
@@ -707,16 +708,20 @@ public class PageBreaker extends AbstractBreaker {
         return layoutRedone;
     }
 
-    protected boolean lastPageHasIPDChange() {
+    protected boolean lastPageHasIPDChange(int optimalPageCount) {
         boolean lastPageMasterDefined = pslm.getPageSequence().hasPagePositionLast();
         boolean onlyPageMasterDefined = pslm.getPageSequence().hasPagePositionOnly();
         if (lastPageMasterDefined && !onlyPageMasterDefined) {
             // code not very robust and unable to handle situations were only and last are defined
+            int currentColumnCount = pageProvider.getCurrentColumnCount();
+            boolean changeInColumnCount = prevousColumnCount > 0 && prevousColumnCount != currentColumnCount;
+            prevousColumnCount = currentColumnCount;
+            if ((currentColumnCount > 1 && optimalPageCount % currentColumnCount == 0) || changeInColumnCount) {
+                return false;
+            }
             int currentIPD = this.pageProvider.getCurrentIPD();
             int lastPageIPD = this.pageProvider.getLastPageIPD();
-            if (lastPageIPD != -1 && currentIPD != lastPageIPD) {
-                return true;
-            }
+            return lastPageIPD != -1 && currentIPD != lastPageIPD;
         }
         return false;
     }
