@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: TableLayoutManager.java 1835810 2018-07-13 10:29:57Z ssteiner $ */
+/* $Id: TableLayoutManager.java 1884907 2020-12-29 13:33:34Z ssteiner $ */
 
 package org.apache.fop.layoutmgr.table;
 
@@ -79,6 +79,7 @@ public class TableLayoutManager extends SpacedBorderedPaddedBlockLayoutManager
     private Block curBlockArea;
 
     private double tableUnit;
+    private double oldTableUnit;
     private boolean autoLayout = true;
 
     private int halfBorderSeparationBPD;
@@ -241,7 +242,8 @@ public class TableLayoutManager extends SpacedBorderedPaddedBlockLayoutManager
          * for proportional-column-width()
          */
         if (tableUnit == 0.0) {
-            this.tableUnit = columns.computeTableUnit(this);
+            tableUnit = columns.computeTableUnit(this);
+            tableUnit = Math.max(tableUnit, oldTableUnit);
         }
 
         if (!firstVisibleMarkServed) {
@@ -379,6 +381,11 @@ public class TableLayoutManager extends SpacedBorderedPaddedBlockLayoutManager
         lc.setRefIPD(getContentAreaIPD());
         contentLM.setStartXOffset(startXOffset);
         contentLM.addAreas(parentIter, lc);
+
+        if (fobj.getUserAgent().isTableBorderOverpaint()) {
+            new OverPaintBorders(curBlockArea);
+        }
+
         tableHeight += contentLM.getUsedBPD();
 
         curBlockArea.setBPD(tableHeight);
@@ -531,6 +538,7 @@ public class TableLayoutManager extends SpacedBorderedPaddedBlockLayoutManager
     public void reset() {
         super.reset();
         curBlockArea = null;
+        oldTableUnit = tableUnit;
         tableUnit = 0.0;
     }
 
