@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: TableStepper.java 1867463 2019-09-24 14:11:21Z ssteiner $ */
+/* $Id: TableStepper.java 1872250 2020-01-02 16:28:29Z ssteiner $ */
 
 package org.apache.fop.layoutmgr.table;
 
@@ -30,14 +30,15 @@ import org.apache.fop.fo.Constants;
 import org.apache.fop.fo.flow.table.EffRow;
 import org.apache.fop.fo.flow.table.GridUnit;
 import org.apache.fop.fo.flow.table.PrimaryGridUnit;
+import org.apache.fop.layoutmgr.BlockStackingLayoutManager;
 import org.apache.fop.layoutmgr.BreakElement;
 import org.apache.fop.layoutmgr.Keep;
 import org.apache.fop.layoutmgr.KnuthBlockBox;
 import org.apache.fop.layoutmgr.KnuthBox;
-import org.apache.fop.layoutmgr.KnuthElement;
 import org.apache.fop.layoutmgr.KnuthGlue;
 import org.apache.fop.layoutmgr.KnuthPenalty;
 import org.apache.fop.layoutmgr.LayoutContext;
+import org.apache.fop.layoutmgr.LayoutManager;
 import org.apache.fop.layoutmgr.Position;
 import org.apache.fop.util.BreakUtil;
 
@@ -274,17 +275,16 @@ public class TableStepper {
 
             laststep = step;
             step = getNextStep();
-
             if (penaltyOrGlueLen < 0) {
-                if (keep.getPenalty() == KnuthElement.INFINITE) {
-                    if (boxLen > -penaltyOrGlueLen && boxLen < maxRemainingHeight) {
-                        returnList.add(new KnuthGlue(boxLen, 0, 0, new Position(null), true));
-                    } else {
-                        returnList.add(new KnuthGlue(0, -penaltyOrGlueLen, 0, new Position(null), true));
-                    }
-                } else {
-                    returnList.add(new KnuthGlue(-penaltyOrGlueLen, 0, 0, new Position(null), true));
+                int shrink = 0;
+                int stretch = 0;
+                int width = -penaltyOrGlueLen;
+                LayoutManager bslm = getTableLM().getParent();
+                if (bslm instanceof BlockStackingLayoutManager && ((BlockStackingLayoutManager)bslm).isRestartAtLM()
+                        && keep.getPenalty() == KnuthPenalty.INFINITE) {
+                    width = 0;
                 }
+                returnList.add(new KnuthGlue(width, stretch, shrink, new Position(null), true));
             }
         } while (step >= 0);
         assert !returnList.isEmpty();
