@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PDFFactory.java 1863870 2019-07-27 13:23:59Z matthias $ */
+/* $Id: PDFFactory.java 1877589 2020-05-11 15:56:59Z cbowditch $ */
 
 package org.apache.fop.pdf;
 
@@ -518,6 +518,26 @@ public class PDFFactory {
         return link;
     }
 
+    /**
+     * Make an internal link.
+     *
+     * @param rect the hotspot position in absolute coordinates
+     * @param dest the position destination
+     * @param isNamedDestination set to true if dest param is a named destination
+     * @return the new PDF link object
+     */
+    public PDFLink makeLink(Rectangle2D rect, String dest, boolean isNamedDestination) {
+        PDFLink link = new PDFLink(rect);
+        getDocument().registerObject(link);
+
+        PDFAction pdfAction = new PDFGoTo(dest, isNamedDestination);
+        getDocument().registerObject(pdfAction);
+
+        link.setAction(pdfAction);
+
+        return link;
+    }
+
     /**
      * Make a {@link PDFLink} object
      *
