@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: AFPPainter.java 1779051 2017-01-16 15:57:25Z ssteiner $ */
+/* $Id: AFPPainter.java 1884462 2020-12-15 13:28:47Z ssteiner $ */
 
 package org.apache.fop.render.afp;
 
@@ -915,7 +915,7 @@ public class AFPPainter extends AbstractIFPainter<AFPDocumentHandler> {
         final Font font;
         final AFPFont afpFont;
         final CharacterSet charSet;
-        final PresentationTextObject pto;
+        PresentationTextObject pto;
 
         private DefaultPtocaProducer(int x, int y,
                                       final int letterSpacing, final int wordSpacing, final int[][] dp,
@@ -960,7 +960,12 @@ public class AFPPainter extends AbstractIFPainter<AFPDocumentHandler> {
                     page.endPresentationObject();
                 }
                 pto = page.getPresentationTextObject();
-                pto.createControlSequences(this);
+                boolean success = pto.createControlSequences(this);
+                if (!success) {
+                    page.endPresentationObject();
+                    pto = page.getPresentationTextObject();
+                    pto.createControlSequences(this);
+                }
             } catch (IOException ioe) {
                 throw new IFException("I/O error in drawText()", ioe);
             }
