@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: IFSerializer.java 1862426 2019-07-02 13:19:54Z ssteiner $ */
+/* $Id: IFSerializer.java 1875656 2020-03-25 16:36:47Z ssteiner $ */
 
 package org.apache.fop.render.intermediate;
 
@@ -40,9 +40,11 @@ import org.apache.xmlgraphics.util.QName;
 import org.apache.xmlgraphics.util.XMLizable;
 
 import org.apache.fop.accessibility.StructureTreeEventHandler;
+import org.apache.fop.apps.FOUserAgent;
 import org.apache.fop.fo.extensions.InternalElementMapping;
 import org.apache.fop.fonts.FontInfo;
 import org.apache.fop.render.DefaultRendererConfigurator;
+import org.apache.fop.render.RendererEventProducer;
 import org.apache.fop.render.RenderingContext;
 import org.apache.fop.render.intermediate.IFRendererConfig.IFRendererConfigParser;
 import org.apache.fop.render.intermediate.IFStructureTreeBuilder.IFStructureTreeElement;
@@ -85,6 +87,7 @@ implements IFConstants, IFPainter, IFDocumentNavigationHandler {
     private String currentID = "";
 
     private IFStructureTreeBuilder structureTreeBuilder;
+    private int pageNumberEnded;
 
     public IFSerializer(IFContext context) {
         super(context);
@@ -384,6 +387,11 @@ implements IFConstants, IFPainter, IFDocumentNavigationHandler {
         } catch (SAXException e) {
             throw new IFException("SAX error in endPage()", e);
         }
+        if (mimicHandler != null) {
+            pageNumberEnded++;
+            FOUserAgent userAgent = mimicHandler.getContext().getUserAgent();
+            RendererEventProducer.Provider.get(userAgent.getEventBroadcaster()).endPage(this, pageNumberEnded);
+        }
     }
 
     //---=== IFPainter ===---
@@ -412,6 +420,9 @@ implements IFConstants, IFPainter, IFDocumentNavigationHandler {
             if (clipRect != null) {
                 addAttribute(atts, "clip-rect", IFUtil.toString(clipRect));
             }
+            if (getUserAgent().isAccessibilityEnabled() && getContext().getRegionType() != null) {
+                addAttribute(atts, "region-type", getContext().getRegionType());
+            }
             handler.startElement(EL_VIEWPORT, atts);
         } catch (SAXException e) {
             throw new IFException("SAX error in startViewport()", e);
