@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: PDFGraphics2D.java 1761020 2016-09-16 11:17:35Z ssteiner $ */
+/* $Id: PDFGraphics2D.java 1877589 2020-05-11 15:56:59Z cbowditch $ */
 
 package org.apache.fop.svg;
 
@@ -421,9 +421,15 @@ public class PDFGraphics2D extends AbstractGraphics2D implements NativeImageHand
             Rectangle rect = b.getBounds();
 
             if (linkType != PDFLink.EXTERNAL) {
-                String pdfdest = "/FitR " + dest;
-                resourceContext.addAnnotation(
-                    pdfDoc.getFactory().makeLink(rect, getPageReference().toString(), pdfdest));
+                if (dest.startsWith("#")) {
+                    String idDest = dest.substring(1);
+                    resourceContext.addAnnotation(
+                            pdfDoc.getFactory().makeLink(rect, idDest, true));
+                } else {
+                    String pdfdest = "/FitR " + dest;
+                    resourceContext.addAnnotation(
+                            pdfDoc.getFactory().makeLink(rect, getPageReference().toString(), pdfdest));
+                }
             } else {
                 resourceContext.addAnnotation(
                     pdfDoc.getFactory().makeLink(rect, dest, linkType, 0));
